@@ -57,8 +57,8 @@ class SearchEngines:
             {"name":"QuickBar","url":"None","icon":"quickbar.png","prefix":None},
             {"name":"Wikipedia","url":"http://en.wikipedia.org/w/index.php?title=Special%%3ASearch&search=%s&fulltext=Search","icon":"wikipedia.png","prefix":"w"},
             {"name":"eBay","url":"http://shop.ebay.com/?_from=R40&_trksid=p3907.m38.l1313&_nkw=%s&=&_sacat=See-All-Categories","icon":"ebay.png","prefix":"e"},
+            {"name":"Amazon","url":"http://www.amazon.com/s?&tag=ts-222-20&camp=211041&creative=374001&linkCode=qs1&field-keywords=%s","icon":"amazon.png","prefix":"a"},
             {"name":"Google Maps Mobile","url":"http://www.google.com/maps/m#ll=&q=%s","icon":"google_maps.png","prefix":"gm"},
-            {"name":"Amazon","url":"http://www.amazon.com/s/ref=nb_ss?url=search-alias%%3Daps&field-keywords=%s&x=0&y=0","icon":"amazon.png","prefix":"a"},
             {"name":"Dictionary.com","url":"http://m.reference.com/d/search.html?q=%s","icon":"dictionary.png","prefix":"d"},
             {"name":"IMDb","url":"http://www.imdb.com/find?s=all&q=%s","icon":"imdb.png","prefix":"i"},
             {"name":"YouTube","url":"http://www.youtube.com/results?search_query=%s&search_type=&aq=f","icon":"youtube.png","prefix":"y"},
@@ -619,7 +619,10 @@ License along with this program.  If not, see
       url_entry = hildon.Entry(gtk.HILDON_SIZE_AUTO)
       url_entry.set_text(engine['url'])
       prefix_entry = hildon.Entry(gtk.HILDON_SIZE_AUTO)
-      prefix_entry.set_text(engine['prefix'])
+      try:
+         prefix_entry.set_text(engine['prefix'])
+      except KeyError:
+         prefix_entry.set_text("")
       prefix_entry.set_max_length(3)
       
       name_hbox = gtk.HBox()
